#  Copyright (c) maiot GmbH 2020. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.

from zenml.steps.evaluator.agnostic_evaluator import AgnosticEvaluator
from zenml.steps.evaluator.base_evaluator import BaseEvaluatorStep
from zenml.steps.evaluator.tfma_evaluator import TFMAEvaluator



#  Copyright (c) maiot GmbH 2020. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the 'License');
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an 'AS IS' BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.

DATA_SPLIT_NAME = 'examples'
DATA_COL = '_data_'

# local storage data source args
BINARY_DATA = 'binary_data'
METADATA = 'metadata'
FILE_EXT = 'file_ext'
FILE_NAME = 'file_name'
IMAGE = "image"

# image data constants
LABEL = 'label'

